About ETE — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- previous |
- ETE documentation »

# About ETE

ETE is currently developed by the Comparative genomics group at the Centre for Genomic Regulation

You can cite ETE as:

Jaime Huerta-Cepas, Joaquín Dopazo and Toni Gabaldón. ETE: a python Environment for Tree Exploration. BMC Bioinformatics 2010, 11:24.

## People using ETE

Warning

UNDER CONSTRUCTION

### Navigation

- index
- modules |
- previous |
- ETE documentation »